==> libgal-0.2.0.tar.gz: libgal-0.2.0/eao/gal_eors.c <==
/*  
 *  - - - - - - - - -  
 *   g a l _ e o r s  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Equation of the origins, given the classical NPB matrix and the  
 *  quantity s.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     rnpb             d[3][3]     classical nutation x precession x bias matrix  
 *     s                   d        the quantity s (the CIO locator)  
 *  
 *  Returned:
 *  
 *     gal_eors            d        the equation of the origins in radians.  
 *  
 *  Notes:  
 *  
 *  1)  The equation of the origins is the distance between the true  
 *      equinox and the celestial intermediate origin and, equivalently,  
 *      the difference between Earth rotation angle and Greenwich  
 *      apparent sidereal time (ERA-GST).  It comprises the precession  
 *      (since J2000.0) in right ascension plus the equation of the  
 *      equinoxes (including the small correction terms).  
 *  
 *  2)  The algorithm is from Wallace & Capitaine (2006).  
 *  
 *  References:  
 *  
 *     Capitaine, N. & Wallace, P.T., 2006, Astron.Astrophys. 450, 855  
 *  
 *     Wallace, P. & Capitaine, N., 2006, A&A (submitted)  
 *  
 *  This revision:
 *  
 *     2006 November 2 ( c version 2008 January 18 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>  
#include "gal_eors.h"  
  
double  
gal_eors  
 (  
    double rnpb[3][3],  
    double s  
 )  
{  
  
    double x, ax, xs, ys, zs, p, q ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*  
 * Evaluate Wallace & Capitaine (2006) expression (16).  
 */  
  
    x = rnpb[0][2] ;  
    ax = x / ( 1.0 + rnpb[2][2] ) ;  
    xs = 1.0 - ax * x ;  
    ys = -ax * rnpb[1][2] ;  
    zs = -x ;  
    p = rnpb[0][0] * xs +  
        rnpb[1][0] * ys +  
        rnpb[2][0] * zs ;  
    q = rnpb[0][1] * xs +  
        rnpb[1][1] * ys +  
        rnpb[2][1] * zs ;  
    if ( p != 0.0 || q != 0.0 ) {  
        return s - atan2 ( q, p ) ;  
    }  
    else {  
        return s ;  
    }  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */

==> libgal-0.5.0.tar.gz: libgal-0.5.0/eao/gal_eors.c <==
/*  
 *  - - - - - - - - -  
 *   g a l _ e o r s  
 *  - - - - - - - - -  
 *  
 *  This routine is part of the General Astrodynamics Library  
 *  
 *  Description: 
 *  
 *  Equation of the origins, given the classical NPB matrix and the  
 *  quantity s.  
 *  
 *  This routine is an independent translation of a FORTRAN routine  
 *  that is part of IAU's SOFA software collection.  
 *  
 *  Status:
 *  
 *     support routine.  
 *  
 *  Given:
 *  
 *     rnpb             d[3][3]     classical nutation x precession x bias matrix  
 *     s                   d        the quantity s (the CIO locator)  
 *  
 *  Returned:
 *  
 *     gal_eors            d        the equation of the origins in radians.  
 *  
 *  Notes:  
 *  
 *  1)  The equation of the origins is the distance between the true  
 *      equinox and the celestial intermediate origin and, equivalently,  
 *      the difference between Earth rotation angle and Greenwich  
 *      apparent sidereal time (ERA-GST).  It comprises the precession  
 *      (since J2000.0) in right ascension plus the equation of the  
 *      equinoxes (including the small correction terms).  
 *  
 *  2)  The algorithm is from Wallace & Capitaine (2006).  
 *  
 *  References:  
 *  
 *     Capitaine, N. & Wallace, P.T., 2006, Astron.Astrophys. 450, 855  
 *  
 *     Wallace, P. & Capitaine, N., 2006, A&A (submitted)  
 *  
 *  This revision:
 *  
 *     2006 November 2 ( c version 2008 January 18 )  
 *  
 *  
 *  Copyright (C) 2008 Paul C. L. Willmott. See notes at end.  
 *  
 *-----------------------------------------------------------------------  
 */  
  
#include <math.h>  
#include "gal_eors.h"  
  
double  
gal_eors  
 (  
    double rnpb[3][3],  
    double s  
 )  
{  
  
    double x, ax, xs, ys, zs, p, q ;  
  
/*  
 * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  
 */  
  
/*  
 * Evaluate Wallace & Capitaine (2006) expression (16).  
 */  
  
    x = rnpb[2][0] ;  
    ax = x / ( 1.0 + rnpb[2][2] ) ;  
    xs = 1.0 - ax * x ;  
    ys = -ax * rnpb[2][1] ;  
    zs = -x ;  
    p = rnpb[0][0] * xs + rnpb[0][1] * ys + rnpb[0][2] * zs ;  
    q = rnpb[1][0] * xs + rnpb[1][1] * ys + rnpb[1][2] * zs ;  
    return ( ( p != 0 ) || ( q != 0 ) ) ? s - atan2 ( q, p ) : s ;  
  
/*  
 * Finished.  
 */  
  
}  
  
/*  
 *  gal - General Astrodynamics Library  
 *  Copyright (C) 2008 Paul C. L. Willmott  
 *  
 *  This program is free software; you can redistribute it and/or modify  
 *  it under the terms of the GNU General Public License as published by  
 *  the Free Software Foundation; either version 2 of the License, or  
 *  (at your option) any later version.  
 *  
 *  This program is distributed in the hope that it will be useful,  
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of  
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
 *  GNU General Public License for more details.  
 *  
 *  You should have received a copy of the GNU General Public License along  
 *  with this program; if not, write to the Free Software Foundation, Inc.,  
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.  
 *  
 *  Contact:  
 *  
 *  Paul Willmott  
 *  vp9mu@amsat.org  
 */
